__version__ = "0.1"
user_agent = "rimudns/%s" % __version__
rimu_base_url = 'https://rimuhosting.com'
zonomi_base_url = 'https://zonomi.com/app'